Learn R Programming

Kifidi (version 0.1.0)

Kifidi-package: Kifidi package by Oswald Omuron

Description

Kifidi v.0.1.0

Arguments

Author

Oswald Omuron

Maintainer: Oswald Omuron <oswaldomuron@gmail.com>

Details

Package: Kifidi
Type: Package
Title: Kifidi v.0.1.0
Version: 0.1.0
Author: Oswald Omuron
Maintainer: Oswald Omuron <oswaldomuron@gmail.com>
Description: An overview of how to use the package, including the most important functions under See Also below.
License: GPL-3

References

https://github.com/OswaldOmuron/Kifidi

See Also

Optional links to other man pages, e.g. summarize_data, plot_means